isError property
bool
get
isError
Whether or the not the result was an error
Implementation
bool get isError => this is Error<T, E>;
Whether or the not the result was an error
bool get isError => this is Error<T, E>;