isSuccess property
bool
get
isSuccess
Whether or not that the result was a success
Implementation
bool get isSuccess => this is Success<T, E>;
Whether or not that the result was a success
bool get isSuccess => this is Success<T, E>;